/*
 * JODG Library
 * 
 *   Copyright (C) 2020, Jonathan Sevy <jsevy@jsevy.com>
 *   
 *   Permission is hereby granted, free of charge, to any person obtaining a copy
 *   of this software and associated documentation files (the "Software"), to deal
 *   in the Software without restriction, including without limitation the rights
 *   to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *   copies of the Software, and to permit persons to whom the Software is
 *   furnished to do so, subject to the following conditions:
 *   
 *   The above copyright notice and this permission notice shall be included in all
 *   copies or substantial portions of the Software.
 *   
 *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *   SOFTWARE.
 * 
 */


package com.jsevy.jodg;


import java.awt.geom.AffineTransform;



/**
 * Class representing an elliptical arc.
 * 
 * @author jsevy
 *
 */
class ODGEllipse extends ODGCircle
{
    protected double xRadius;	
    protected double yRadius;		
    
    
    /**
     * Create an elliptical arc corresponding to the specified parameters.
     * 
     * @param center        Center of the ellipse, as a RealPoint
     * @param xRadius       Radius of the ellipse along the x-axis
     * @param yRadius       Radius of the ellipse along the y-axis
     * @param startAngle    Starting angle of the circle, in degrees, counterclockwise from the positive x axis
     * @param sweepAngle    Sweep angle of the circle, in degrees, with positive being counterclockwise from the positive x axis
     * @param style         The ODGStyle object specifying rendering parameters for the shape (color, thickness, etc.)
     * @param transform     Affine transform to be applied to the shape
     */
    public ODGEllipse(RealPoint center, double xRadius, double yRadius, double startAngle, double sweepAngle, ODGGraphicsStyle style, AffineTransform transform)
    {
        super(center, xRadius, startAngle, sweepAngle, style, transform);
        
        this.xRadius = xRadius;
        this.yRadius = yRadius;
        
        repopulateXML();
    }
    
    
    /**
     * Fix up XML prepoulated by base class
     */
    private void repopulateXML()
    {
        this.setNodeName("draw:ellipse");
        
        // remove generic radius attribute
        this.removeAttribute("svg:r");
        
        // x- and y-specific radii
        this.setAttribute("svg:rx", scaleValueWithUnits(xRadius));
        this.setAttribute("svg:ry", scaleValueWithUnits(yRadius));
        
    }
    
    
    
    
    
}