/*
 * JODG Library
 * 
 *   Copyright (C) 2020, Jonathan Sevy <jsevy@jsevy.com>
 *   
 *   Permission is hereby granted, free of charge, to any person obtaining a copy
 *   of this software and associated documentation files (the "Software"), to deal
 *   in the Software without restriction, including without limitation the rights
 *   to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *   copies of the Software, and to permit persons to whom the Software is
 *   furnished to do so, subject to the following conditions:
 *   
 *   The above copyright notice and this permission notice shall be included in all
 *   copies or substantial portions of the Software.
 *   
 *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *   SOFTWARE.
 * 
 */

package com.jsevy.jodg;


import java.awt.geom.AffineTransform;

import com.jsevy.jxml.XMLElement;




/**
 * Class representing a box containing text, located at a specified position and having specified style (font, size).
 * 
 * @author jsevy
 *
 */
class ODGTextBox extends ODGEntity
{
    private String text;
    private ODGTextStyle textStyle;
    
    
    /**
     * Create a text object at the specified position.
     * 
     * @param text		    Text string
     * @param textStyle     The ODGStyle object specifying rendering parameters for the text (color, font, etc.)
     * @param transform     Affine transform to be applied to the shape
     */
    public ODGTextBox(String text, ODGTextStyle textStyle, AffineTransform transform)
    {
        super(transform);
        
        this.text = text;
        this.textStyle = textStyle;
        
        populateXML();
    }
    
    /**
     * Populate XMLNode fields for XML generation
     */
    protected void populateXML()
    {
        // add transform attribute if any
        super.populateXML();
        
        // text-box is pretty much just a dummy container
        // all the action is in its child paragraph node
        this.setNodeName("draw:text-box");
        
        // have a paragraph node inside the box, and a text node inside the paragraph
        XMLElement paragraphNode = new XMLElement();
        paragraphNode.setNodeName("text:p");
        
        // add the text node within the paragraph
        XMLElement textNode = new XMLElement();
        textNode.setNodeName("text:span");
        
        // set text
        textNode.setTextContent(text);
        
        // add attributes
        textNode.setAttribute("text:style-name", textStyle.getStyleName());
        
        // now add text element as child of paragraph, and paragraph as child of textBox
        paragraphNode.appendChild(textNode);
        this.appendChild(paragraphNode);
        
        
        
        
    }
    
    
}